## __20080529__
'.onLoad' <- function(lib, pkg="bayesGARCH")
{
  cat("\nLoading 'bayesGARCH' package...\n")
  cat("Version 1.00-02\n")
  cat("Bayesian Estimation of the GARCH(1,1) Model with Student-t Innovations\n")
  cat("Author and maintainer: David Ardia <david.ardia@unifr.ch>\n")
}
